@@ -119,6 +119,7 @@ class IP:
         else:
             self.ip_yml_hash  = ""
         self.is_licensed                                   = False
+        self.from_ip_server                                = False
         self.code_timestamp                                = ""
         self.fresh_code_timestamp                          = ""
         self.is_installed                                  = False # TODO Use package manager lib to resolve this
@@ -207,6 +208,9 @@ class IP:
                 self.full_name = yml["ip"]["full-name"].strip()
                 self.type      = yml["ip"]["type"].strip().lower()
                 
+                if 'from_ip_server' in yml["ip"]:
+                    self.from_ip_server = yml["ip"]["from_ip_server"]
+                
                 if 'vendor' in yml["ip"]:
                     self.vendor = yml["ip"]["vendor"].strip().lower()
                 if 'sub-type' in yml["ip"]:
@@ -343,6 +347,7 @@ class IP:
             self.is_licensed       = yml['is_licensed']
             self.is_local          = yml['is_local']
             self.is_global         = yml['is_global']
+            self.from_ip_server    = yml['from_ip_server']
             self.path              = yml['path']
             self.name              = yml['name']
             self.ip_yml_hash       = yml['ip_yml_hash']
@@ -433,6 +438,7 @@ class IP:
         dict['is_licensed']                 = self.is_licensed
         dict['is_local']                    = self.is_local
         dict['is_global']                   = self.is_global
+        dict['from_ip_server']              = self.from_ip_server
         dict['path']                        = self.path
         dict['name']                        = self.name
         dict['ip_yml_hash']                 = self.ip_yml_hash
@@ -632,7 +638,8 @@ class IP:
         for dep in self.dependencies:
             dep_ip = get_ip(dep.vendor, dep.target_ip)
             if dep_ip != None:
-                if not dep_ip.is_local:
+                if dep_ip.from_ip_server:
+                    common.dbg(f"Deleting dependency '{dep.vendor}/{dep.target_ip}'")
                     dep_ip.delete_local_files()
     
     def delete_local_files(self):
@@ -778,8 +785,9 @@ def check_ip_cache_integrity():
                 list[vendor].append(ip)
     for vendor in list:
         for ip in list[vendor]:
-            ip_cache[vendor].pop(ip)
-            common.warning(f"Removed IP '{vendor}/{ip}' from cache")
+            removed_ip = ip_cache[vendor].pop(ip)
+            if not removed_ip.from_ip_server:
+                common.warning(f"Removed IP '{vendor}/{ip}' from cache")
 
 
 def check_core_cache_integrity():
