@@ -1,5 +1,5 @@
 # Copyright 2021-2023 Datum Technology Corporation
-# SPDX-License-Identifier: GPL-3.0-or-later
+# SPDX-License-Identifier: GPL-3.0
 ########################################################################################################################
 
 from mio import user
@@ -977,7 +977,7 @@ def do_simulate(ip, sim_job, wd):
         sim_job.bwrap_commands += launch_eda_bin(cfg.metrics_home + "/mdc", ["download", mtr_simulation_log_path], wd=cfg.project_dir, dry_run=sim_job.dry_run)
         if not sim_job.dry_run:
             common.move_file(f"{cfg.project_dir}/_downloaded_{mtr_simulation_log_path}", simulation_log_path)
-            common.info("Downloading simulation artifacts ...")
+            common.info("Downloading UVMx simulation artifacts ...")
             download_uvmx_logs_mdc(sim_job, mdc_tests_results_path, tests_results_path)
             if sim_job.waves:
                 common.remove_file(f"{cfg.project_dir}/_downloaded_{test_result_dir}.vcd")
