@@ -92,6 +92,8 @@ def install_ip(vendor, name, global_install, username="", password=""):
     if not found_payload:
         common.fatal(f"Could not find IP '{vendor}/{name}' on Moore.io IP Marketplace")
     
+    update_installed_ip_file(ip_destination_path)
+    
     return version_str
 
 
@@ -185,3 +187,15 @@ def update_lock_file(ip, versions={}):
     except Exception as e:
         common.fatal(f"Failed to update '{lock_file_path}': {e}")
 
+
+def update_installed_ip_file(path):
+    ip_file_path = path + "/ip.yml"
+    try:
+        with open(ip_file_path, 'r') as yaml_file_read:
+            ymlr = yaml.load(yaml_file_read, Loader=SafeLoader)
+            ymlr['ip']['from_ip_server'] = True
+        with open(ip_file_path, 'w') as yaml_file_write:
+            yaml.dump(ymlr, yaml_file_write)
+    except Exception as e:
+        common.fatal(f"Failed to update '{path}/ip.yml' after installation: {e}")
+
