@@ -260,10 +260,10 @@ class TestSuite:
                 test_count = len(self.regr[regr].tests)
         if test_count == 0:
             common.fatal("Regression describes no tests.  Please add entries and try again.")
+        if test_count > 1000000:
+            common.fatal("Regression describes more than 1,000,000 tests.  Please reduce this and try again.")
         if test_count > 1000:
-            common.fatal("Regression describes more than 1,000 tests.  Please reduce this and try again.")
-        if test_count > 100:
-            common.warning(f"Regression describes more than 100 tests ({test_count})")
+            common.warning(f"Regression describes more than 1,000 tests ({test_count})")
         #for wave in self.waves:
         #    if wave not in self.regr:
         #        common.fatal(f"'waves' entry '{wave}' is not a regression declared in this test suite")
@@ -543,7 +543,7 @@ def launch_sim_jobs(ip, test_suite, regression, sim_job_list, dry_mode):
         regression_name = f"{cfg.test_suite_name}.{cfg.regression_name}"
         common.banner(f"Running regression '{cfg.regression_name}' from test suite '{cfg.test_suite_name}': {str(len(sim_job_list))} test(s) with {str(regression.max_duration)} hour(s) timeout")
     
-    common.create_dir(cfg.regr_results_dir + "/" + cfg.target_ip_name + "__" + regression_name + "__" + test_suite.timestamp)
+    #common.create_dir(cfg.regr_results_dir + "/" + cfg.target_ip_name + "__" + regression_name + "__" + test_suite.timestamp)
     
     for sim_job in sim_job_list:
         # TEMPORARY UNTIL METRICS REGRESSION SYSTEM IS LIVE
